# freshlinks

_Basic link checker._

[![Build Status](https://img.shields.io/github/actions/workflow/status/metaist/freshlinks/.github/workflows/ci.yaml?branch=main&style=for-the-badge)](https://github.com/metaist/freshlinks/actions)
[![freshlinks on PyPI](https://img.shields.io/pypi/v/freshlinks.svg?color=blue&style=for-the-badge)](https://pypi.org/project/freshlinks)
[![Supported Python versions](https://img.shields.io/pypi/pyversions/freshlinks?style=for-the-badge)](https://pypi.org/project/freshlinks)

[Changelog] - [Issues] - [Documentation]

[changelog]: https://github.com/metaist/freshlinks/blob/main/CHANGELOG.md
[issues]: https://github.com/metaist/freshlinks/issues
[documentation]: https://metaist.github.io/freshlinks/

## Why?

There are lots of existing services out there that have lots of bells and whistles, but I just want to include small fast link checker as part of my build / lint process.

## Quick Start

```bash
python -m freshlinks "https://example.com/"
```

## License

[MIT License](https://github.com/metaist/freshlinks/blob/main/LICENSE.md)
